[media] v4l2-mc: add a routine to create USB media_device

Instead of copying exactly the same code on all USB devices,
add an ancillary routine that will create and fill the
struct media_device with the values imported from the USB
device.

Signed-off-by: Mauro Carvalho Chehab <mchehab@osg.samsung.com>
diff --git a/include/media/v4l2-mc.h b/include/media/v4l2-mc.h
index 20f1ee2..79d84bb 100644
--- a/include/media/v4l2-mc.h
+++ b/include/media/v4l2-mc.h
@@ -95,8 +95,9 @@
 	DEMOD_NUM_PADS
 };
 
-
-struct pci_dev;		/* We don't need to include pci.h here */
+/* We don't need to include pci.h or usb.h here */
+struct pci_dev;
+struct usb_device;
 
 #ifdef CONFIG_MEDIA_CONTROLLER
 /**
@@ -124,8 +125,24 @@
  *		name for the pci device, given by pci_name() macro.
  */
 struct media_device *v4l2_mc_pci_media_device_init(struct pci_dev *pci_dev,
-						   char *name);
-
+						   const char *name);
+/**
+ * __v4l2_mc_usb_media_device_init() - create and initialize a
+ *	struct &media_device from a PCI device.
+ *
+ * @udev:	pointer to struct usb_device
+ * @board_name:	media device name. If %NULL, the routine will use the usb
+ *		product name, if available.
+ * @driver_name: name of the driver. if %NULL, the routine will use the name
+ *		given by udev->dev->driver->name, with is usually the wrong
+ *		thing to do.
+ *
+ * NOTE: It is better to call v4l2_mc_usb_media_device_init() instead, as
+ * such macro fills driver_name with %KBUILD_MODNAME.
+ */
+struct media_device *__v4l2_mc_usb_media_device_init(struct usb_device *udev,
+						     const char *board_name,
+						     const char *driver_name);
 
 #else
 static inline int v4l2_mc_create_media_graph(struct media_device *mdev)
@@ -133,11 +150,23 @@
 	return 0;
 }
 
+static inline
 struct media_device *v4l2_mc_pci_media_device_init(struct pci_dev *pci_dev,
-						   char *name) {
+						   char *name)
+{
 	return NULL;
 }
 
+static inline
+struct media_device *__v4l2_mc_usb_media_device_init(struct usb_device *udev,
+						     char *board_name,
+						     char *driver_name)
+{
+	return NULL;
+}
 #endif
 
+#define v4l2_mc_usb_media_device_init(udev, name) \
+	__v4l2_mc_usb_media_device_init(udev, name, KBUILD_MODNAME)
+
 #endif